@@ -19,10 +19,14 @@
 #'  at each silo. If `FALSE` (default) uses covariates from the `init.csv`.
 #' @param freq_multiplier A numeric value or `FALSE` (default).
 #'  Specify if the frequency should be multiplied by a non-zero integer.
-#' @param weights A character indicating the weighting to use in the case of
-#'  common adoption. The `"standard"` (default) weight is calculated as
-#'  \eqn{w_s = \frac{N_s^{\text{post}}}{N_s^{\text{post}} + N_s^{\text{pre}}}}.
-#'  Options are: `"standard"`.
+#' @param weights A character indicating the weighting to use. The options are
+#'  `"none"`, `"diff"`, `"att"`, and `"both"`. The options reflect the levels at
+#'   which weights are applied. `"diff"` uses weights based off of the number
+#'   of observations (treated and untreated) when calculating the subaggregate
+#'   ATTs. `"att"` uses weights based off of the number of treated observations
+#'   associated with each subaggregate ATT when calculating the aggregate ATT.
+#'   `"both"` applies weighting at both levels, and `"none"` does not use
+#'   weights at all. Defaults to `"both"`.
 #' @param filename A character filename for the created CSV file. Defaults to
 #'  `"empty_diff_df.csv"`
 #' @param filepath Filepath to save the CSV file. Defaults to `tempdir()`.
@@ -44,7 +48,7 @@
 #' @importFrom utils read.csv write.csv
 #' @export
 create_diff_df <- function(init_filepath, date_format, freq, covariates = FALSE,
-                           freq_multiplier = FALSE, weights = "standard",
+                           freq_multiplier = FALSE, weights = "both",
                            filename = "empty_diff_df.csv",
                            filepath = tempdir()) {
 
@@ -82,26 +86,36 @@ create_diff_df <- function(init_filepath, date_format, freq, covariates = FALSE,
   # Ensure that start times < treat times < end times
   .start_treat_end_time_check(init_df, date_format)
 
-
   # Process freq_multiplier and freq
   freq_string <- .parse_freq_freq_multiplier(freq, freq_multiplier)
 
   # Consider the case of common adoption
+  common_adoption <- FALSE
+  staggered_adoption <- FALSE
   if (length(unique(init_df$treatment_time)) == 2) {
-    diff_df <- .create_common_diff_df(init_df, weights)
-
+    diff_df <- .create_common_diff_df(init_df, date_format)
+    common_adoption <- TRUE
     # Consider the case of staggered adoption
   } else if (length(unique(init_df$treatment_time)) > 2) {
     diff_df <- .create_staggered_diff_df(init_df, date_format, freq_string)
+    staggered_adoption <- TRUE
   } else {
-    stop("Only one unique `treatment_time` value found.")
+    stop("Only one unique `treatment_time` value found (including controls).")
   }
 
-  # Add the diff_estimate columns
-  diff_df$diff_estimate <- rep(NA_real_, nrow(diff_df))
-  diff_df$diff_var <- rep(NA_real_, nrow(diff_df))
-  diff_df$diff_estimate_covariates <- rep(NA_real_, nrow(diff_df))
-  diff_df$diff_var_covariates <- rep(NA_real_, nrow(diff_df))
+
+ # silo_name,treat,common_treatment_time,start_time,end_time,weights,diff_estimate,diff_var,diff_estimate_covariates,diff_var_covariates,covariates,date_format,freq,n,n_t,anonymize_size
+
+  # Add the diff_estimate columns, weights (and n & n_t), anon_size
+  nrows <- nrow(diff_df)
+  diff_df$diff_estimate <- rep(NA_real_, nrows)
+  diff_df$diff_var <- rep(NA_real_, nrows)
+  diff_df$diff_estimate_covariates <- rep(NA_real_, nrows)
+  diff_df$diff_var_covariates <- rep(NA_real_, nrows)
+  diff_df$weights <- rep(weights, nrows)
+  diff_df$n <- rep(NA, nrows)
+  diff_df$n_t <- rep(NA, nrows)
+  diff_df$anonymize_size <- rep(NA, nrows)
 
   # Add the covariates if they exist
   if (identical(covariates, FALSE)) {
@@ -113,14 +127,31 @@ create_diff_df <- function(init_filepath, date_format, freq, covariates = FALSE,
   } else {
     covariates <- paste(covariates, collapse = ";")
   }
-  diff_df$covariates <- rep(covariates, nrow(diff_df))
+  diff_df$covariates <- rep(covariates, nrows)
 
   # Note date_format and freq info
   if (date_format %in% .undid_env$date_formats_r) {
     date_format <- .undid_env$date_format_dict_from_r[date_format]
   }
-  diff_df$date_format <- rep(date_format, nrow(diff_df))
-  diff_df$freq <- rep(freq_string, nrow(diff_df))
+  diff_df$date_format <- rep(date_format, nrows)
+  diff_df$freq <- rep(freq_string, nrows)
+
+  # Re-organize columns
+  if (common_adoption) {
+    diff_df <- diff_df[, c("silo_name", "treat", "common_treatment_time",
+                           "start_time", "end_time", "weights",
+                           "diff_estimate", "diff_var",
+                           "diff_estimate_covariates", "diff_var_covariates",
+                           "covariates", "date_format", "freq",
+                           "n", "n_t", "anonymize_size")]
+  } else if (staggered_adoption) {
+    diff_df <- diff_df[, c("silo_name", "gvar", "treat", "diff_times",
+                           "gt", "RI", "start_time", "end_time",
+                           "weights", "diff_estimate", "diff_var",
+                           "diff_estimate_covariates", "diff_var_covariates",
+                           "covariates", "date_format", "freq",
+                           "n", "n_t", "anonymize_size")]
+  }
 
   full_path <- file.path(filepath, filename)
   # Save as csv, print filepath, return dataframe
@@ -158,7 +189,7 @@ create_diff_df <- function(init_filepath, date_format, freq, covariates = FALSE,
 
 #' @keywords internal
 # Create empty_diff_df.csv for common treatment time
-.create_common_diff_df <- function(init_df, weights) {
+.create_common_diff_df <- function(init_df, date_format) {
   silo_name <- c()
   treat <- c()
   common_treatment_time <- rep(init_df[init_df$treatment_time != "control",
@@ -178,15 +209,19 @@ create_diff_df <- function(init_filepath, date_format, freq, covariates = FALSE,
                                     "end_time"])
     silo_name <- c(silo_name, silo)
   }
-  if (weights == "standard") {
-    weights <- rep("standard", nrow(init_df))
-  }
+
   diff_df <- data.frame(silo_name = silo_name, treat = treat,
                         common_treatment_time = common_treatment_time,
-                        start_time = start_time, end_time = end_time,
-                        weights = weights)
-  diff_df$start_time <- as.Date(diff_df$start_time, origin = "1970-01-01")
-  diff_df$end_time <- as.Date(diff_df$end_time, origin = "1970-01-01")
+                        start_time = start_time, end_time = end_time)
+
+  # Transform to a legible date and then to the proper string
+  diff_df$start_time <- .parse_date_to_string(
+    as.Date(diff_df$start_time, origin = "1970-01-01"), date_format
+  )
+  diff_df$end_time <- .parse_date_to_string(
+    as.Date(diff_df$end_time, origin = "1970-01-01"), date_format
+  )
+
   return(diff_df)
 }
 
